@@ -4,7 +4,7 @@ require './t/testlib/CDBase.pm';
 @ISA = 'CDBase';
 use strict;
 
-__PACKAGE__->table("Lazy");
+# __PACKAGE__->table("Lazy");
 __PACKAGE__->columns('Primary', qw(this));
 __PACKAGE__->columns('Essential', qw(opop));
 __PACKAGE__->columns('things', qw(this that));
@@ -14,7 +14,7 @@ __PACKAGE__->columns('vertical', qw(oop opop));
 sub CONSTRUCT {
   my $class = shift;
   $class->db_Main->do(qq{
-    CREATE TABLE Lazy (
+    CREATE TABLE lazy (
         this INTEGER,
         that INTEGER,
         eep  INTEGER,
